# CTAO Data Processing Pipeline Subsystem

This package provides the software and workflow definitions for the [CTAO][1]
_Data Processing and Preservation System_ (DPPS) **Data Processing Pipeline**
subsystem (DataPipe). It is responsible for transforming raw (DL0) observed and
simulated data products produced by the observatory into "science-ready" data
products (DL3), including reconstructed event lists and instrumental response
functions.

- [Documentation][2]
- [Code Repository][3]
- [PyPI: ctao-datapipe](https://pypi.org/project/ctao-datapipe/)

[1]: https://www.ctao.org "CTAO website"
[2]: http://cta-computing.gitlab-pages.cta-observatory.org/dpps/datapipe/datapipe/latest/ "DataPipe documentation"
[3]: https://gitlab.cta-observatory.org/cta-computing/dpps/datapipe/datapipe "DataPipe code"
